@@ -1,10 +1,10 @@
 library(testthat)
 library(FSelectorRcpp)
-library(FSelector)
 library(Matrix)
 library(Rcpp)
 library(RcppArmadillo)
 library(dplyr)
 library(entropy)
+library(lintr)
 
 test_check("FSelectorRcpp")
